@@ -232,6 +232,9 @@ class ComputeGraph(MultiDiGraph):
         elif backend == 'julia':
             from pyrates.backend.julia import JuliaBackend
             backend = JuliaBackend
+        elif backend == 'matlab':
+            from pyrates.backend.matlab import MatlabBackend
+            backend = MatlabBackend
         else:
             from pyrates.backend.base import BaseBackend
             backend = BaseBackend
@@ -354,14 +357,11 @@ class ComputeGraph(MultiDiGraph):
 
         variables = []
         idx = 0
-        #dtype = 'float'
         for var, update in self.var_updates['DEs'].items():
 
             # extract left-hand side nodes from graph
             lhs, rhs = self._process_var_update(var, update)
             variables.append(lhs.value)
-            #if 'complex' in lhs.dtype:
-            #    dtype = 'complex'
 
             # store information of the original, non-vectorized state variable
             vshape = sum(lhs.shape)
@@ -393,7 +393,7 @@ class ComputeGraph(MultiDiGraph):
         code_gen.code.clear()
 
         # generate function head
-        func_args = code_gen.generate_func_head(func_name=func_name, state_var=state_var_key,
+        func_args = code_gen.generate_func_head(func_name=func_name, state_var=state_var_key, return_var=rhs_var_key,
                                                 func_args=[self.get_var(arg) for arg in func_args])
 
         # add lines from function body after function head
